@@ -5,7 +5,7 @@ Writing and reading information to the .sconsign file or files.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,13 +27,13 @@ Writing and reading information to the .sconsign file or files.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/SConsign.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/SConsign.py 5357 2011/09/09 21:31:03 bdeegan"
 
 import SCons.compat
 
-import cPickle
 import os
-import os.path
+# compat layer imports "cPickle" for us if it's available.
+import pickle
 
 import SCons.dblite
 import SCons.Warnings
@@ -104,11 +104,17 @@ def write():
         try:
             syncmethod = db.sync
         except AttributeError:
-            pass # Not all anydbm modules have sync() methods.
+            pass # Not all dbm modules have sync() methods.
         else:
             syncmethod()
+        try:
+            closemethod = db.close
+        except AttributeError:
+            pass # Not all dbm modules have close() methods.
+        else:
+            closemethod()
 
-class SConsignEntry:
+class SConsignEntry(object):
     """
     Wrapper class for the generic entry in a .sconsign file.
     The Node subclass populates it with attributes as it pleases.
@@ -126,7 +132,7 @@ class SConsignEntry:
     def convert_from_sconsign(self, dir, name):
         self.binfo.convert_from_sconsign(dir, name)
 
-class Base:
+class Base(object):
     """
     This is the controlling class for the signatures for the collection of
     entries associated with a specific directory.  The actual directory
@@ -203,8 +209,8 @@ class DB(Base):
             pass
         else:
             try:
-                self.entries = cPickle.loads(rawentries)
-                if type(self.entries) is not type({}):
+                self.entries = pickle.loads(rawentries)
+                if not isinstance(self.entries, dict):
                     self.entries = {}
                     raise TypeError
             except KeyboardInterrupt:
@@ -241,7 +247,7 @@ class DB(Base):
         path = normcase(self.dir.path)
         for key, entry in self.entries.items():
             entry.convert_to_sconsign()
-        db[path] = cPickle.dumps(self.entries, 1)
+        db[path] = pickle.dumps(self.entries, 1)
 
         if sync:
             try:
@@ -262,8 +268,8 @@ class Dir(Base):
         if not fp:
             return
 
-        self.entries = cPickle.load(fp)
-        if type(self.entries) is not type({}):
+        self.entries = pickle.load(fp)
+        if not isinstance(self.entries, dict):
             self.entries = {}
             raise TypeError
 
@@ -329,7 +335,7 @@ class DirFile(Dir):
                 return
         for key, entry in self.entries.items():
             entry.convert_to_sconsign()
-        cPickle.dump(self.entries, file, 1)
+        pickle.dump(self.entries, file, 1)
         file.close()
         if fname != self.sconsign:
             try:
@@ -375,3 +381,9 @@ def File(name, dbm_module=None):
         DB_Name = name
         if not dbm_module is None:
             DB_Module = dbm_module
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
