@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,10 +31,9 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/yacc.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/Tool/yacc.py 5357 2011/09/09 21:31:03 bdeegan"
 
 import os.path
-import string
 
 import SCons.Defaults
 import SCons.Tool
@@ -62,6 +61,16 @@ def _yaccEmitter(target, source, env, ysuf, hsuf):
         base, ext = os.path.splitext(SCons.Util.to_String(source[0]))
         target.append(base + env.subst("$YACCVCGFILESUFFIX"))
 
+    # If -v is specirfied yacc will create the output debug file
+    # which is not really source for any process, but should
+    # be noted and also be cleaned
+    # Bug #2558
+    if "-v" in flags:
+        env.SideEffect(targetBase+'.output',target[0])
+        env.Clean(target[0],targetBase+'.output')
+
+
+
     # With --defines and --graph, the name of the file is totally defined
     # in the options.
     fileGenOptions = ["--defines=", "--graph="]
@@ -71,7 +80,7 @@ def _yaccEmitter(target, source, env, ysuf, hsuf):
             if option[:l] == fileGenOption:
                 # A file generating option is present, so add the file
                 # name to the list of targets.
-                fileName = string.strip(option[l:])
+                fileName = option[l:].strip()
                 target.append(fileName)
 
     return (target, source)
@@ -109,14 +118,23 @@ def generate(env):
     env['YACCCOM']   = '$YACC $YACCFLAGS -o $TARGET $SOURCES'
     env['YACCHFILESUFFIX'] = '.h'
 
-    if env['PLATFORM'] == 'darwin':
-        # Bison on Mac OS X just appends ".h" to the generated target .cc
-        # or .cpp file name.  Hooray for delayed expansion of variables.
-        env['YACCHXXFILESUFFIX'] = '${TARGET.suffix}.h'
-    else:
-        env['YACCHXXFILESUFFIX'] = '.hpp'
+    # Apparently, OS X now creates file.hpp like everybody else
+    # I have no idea when it changed; it was fixed in 10.4
+    #if env['PLATFORM'] == 'darwin':
+    #    # Bison on Mac OS X just appends ".h" to the generated target .cc
+    #    # or .cpp file name.  Hooray for delayed expansion of variables.
+    #    env['YACCHXXFILESUFFIX'] = '${TARGET.suffix}.h'
+    #else:
+    #    env['YACCHXXFILESUFFIX'] = '.hpp'
+    env['YACCHXXFILESUFFIX'] = '.hpp'
 
     env['YACCVCGFILESUFFIX'] = '.vcg'
 
 def exists(env):
     return env.Detect(['bison', 'yacc'])
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
