@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,9 +27,8 @@ This file implements the warnings framework for SCons.
 
 """
 
-__revision__ = "src/engine/SCons/Warnings.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/Warnings.py 5357 2011/09/09 21:31:03 bdeegan"
 
-import string
 import sys
 
 import SCons.Errors
@@ -37,72 +36,124 @@ import SCons.Errors
 class Warning(SCons.Errors.UserError):
     pass
 
+class WarningOnByDefault(Warning):
+    pass
+
 
 # NOTE:  If you add a new warning class, add it to the man page, too!
 
 class CacheWriteErrorWarning(Warning):
     pass
 
-class CorruptSConsignWarning(Warning):
+class CorruptSConsignWarning(WarningOnByDefault):
     pass
 
 class DependencyWarning(Warning):
     pass
 
-class DeprecatedWarning(Warning):
+class DuplicateEnvironmentWarning(WarningOnByDefault):
     pass
 
-class DeprecatedCopyWarning(DeprecatedWarning):
+class FutureReservedVariableWarning(WarningOnByDefault):
     pass
 
-class DeprecatedSourceSignaturesWarning(DeprecatedWarning):
+class LinkWarning(WarningOnByDefault):
     pass
 
-class DeprecatedTargetSignaturesWarning(DeprecatedWarning):
+class MisleadingKeywordsWarning(WarningOnByDefault):
     pass
 
-class DuplicateEnvironmentWarning(Warning):
+class MissingSConscriptWarning(WarningOnByDefault):
     pass
 
-class LinkWarning(Warning):
+class NoMD5ModuleWarning(WarningOnByDefault):
     pass
 
-class MisleadingKeywordsWarning(Warning):
+class NoMetaclassSupportWarning(WarningOnByDefault):
     pass
 
-class MissingSConscriptWarning(Warning):
+class NoObjectCountWarning(WarningOnByDefault):
     pass
 
-class NoMD5ModuleWarning(Warning):
+class NoParallelSupportWarning(WarningOnByDefault):
     pass
 
-class NoMetaclassSupportWarning(Warning):
+class ReservedVariableWarning(WarningOnByDefault):
     pass
 
-class NoObjectCountWarning(Warning):
+class StackSizeWarning(WarningOnByDefault):
     pass
 
-class NoParallelSupportWarning(Warning):
+class VisualCMissingWarning(WarningOnByDefault):
     pass
 
-class PythonVersionWarning(DeprecatedWarning):
+# Used when MSVC_VERSION and MSVS_VERSION do not point to the
+# same version (MSVS_VERSION is deprecated)
+class VisualVersionMismatch(WarningOnByDefault):
     pass
 
-class ReservedVariableWarning(Warning):
-    pass
-
-class StackSizeWarning(Warning):
+class VisualStudioMissingWarning(Warning):
     pass
 
 class FortranCxxMixWarning(LinkWarning):
     pass
 
-_warningAsException = 0
+
+# Deprecation warnings
+
+class FutureDeprecatedWarning(Warning):
+    pass
+
+class DeprecatedWarning(Warning):
+    pass
+
+class MandatoryDeprecatedWarning(DeprecatedWarning):
+    pass
+
+
+# Special case; base always stays DeprecatedWarning
+class PythonVersionWarning(DeprecatedWarning):
+    pass
+
+class DeprecatedSourceCodeWarning(FutureDeprecatedWarning):
+    pass
+
+class DeprecatedBuildDirWarning(DeprecatedWarning):
+    pass
+
+class TaskmasterNeedsExecuteWarning(DeprecatedWarning):
+    pass
+
+class DeprecatedCopyWarning(MandatoryDeprecatedWarning):
+    pass
+
+class DeprecatedOptionsWarning(MandatoryDeprecatedWarning):
+    pass
+
+class DeprecatedSourceSignaturesWarning(MandatoryDeprecatedWarning):
+    pass
+
+class DeprecatedTargetSignaturesWarning(MandatoryDeprecatedWarning):
+    pass
+
+class DeprecatedDebugOptionsWarning(MandatoryDeprecatedWarning):
+    pass
+
+class DeprecatedSigModuleWarning(MandatoryDeprecatedWarning):
+    pass
+
+class DeprecatedBuilderKeywordsWarning(MandatoryDeprecatedWarning):
+    pass
+
 
 # The below is a list of 2-tuples.  The first element is a class object.
 # The second element is true if that class is enabled, false if it is disabled.
 _enabled = []
 
+# If set, raise the warning as an exception
+_warningAsException = 0
+
+# If not None, a function to call with the warning
 _warningOut = None
 
 def suppressWarningClass(clazz):
@@ -111,7 +162,7 @@ def suppressWarningClass(clazz):
     _enabled.insert(0, (clazz, 0))
 
 def enableWarningClass(clazz):
-    """Suppresses all warnings that are of type clazz or
+    """Enables all warnings that are of type clazz or
     derived from clazz."""
     _enabled.insert(0, (clazz, 1))
 
@@ -150,8 +201,7 @@ def process_warn_strings(arguments):
     "Warning" is appended to get the class name.
 
     For example, 'deprecated' will enable the DeprecatedWarning
-    class.  'no-dependency' will disable the .DependencyWarning
-    class.
+    class.  'no-dependency' will disable the DependencyWarning class.
 
     As a special case, --warn=all and --warn=no-all will enable or
     disable (respectively) the base Warning class of all warnings.
@@ -162,11 +212,11 @@ def process_warn_strings(arguments):
         if s[:5] == "scons":
             return "SCons" + s[5:]
         else:
-            return string.capitalize(s)
+            return s.capitalize()
 
     for arg in arguments:
 
-        elems = string.split(string.lower(arg), '-')
+        elems = arg.lower().split('-')
         enable = 1
         if elems[0] == 'no':
             enable = 0
@@ -175,7 +225,7 @@ def process_warn_strings(arguments):
         if len(elems) == 1 and elems[0] == 'all':
             class_name = "Warning"
         else:
-            class_name = string.join(map(_capitalize, elems), '') + "Warning"
+            class_name = ''.join(map(_capitalize, elems)) + "Warning"
         try:
             clazz = globals()[class_name]
         except KeyError:
@@ -183,5 +233,14 @@ def process_warn_strings(arguments):
         else:
             if enable:
                 enableWarningClass(clazz)
+            elif issubclass(clazz, MandatoryDeprecatedWarning):
+                fmt = "Can not disable mandataory warning: '%s'\n"
+                sys.stderr.write(fmt % arg)
             else:
                 suppressWarningClass(clazz)
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
